<?php
    /**
     * @var View         $this
     * @var string       $content
     * @var SeoComponent $seo
     * @var User         $user
     */
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use artbox\core\models\Feedback;
    use artbox\core\models\Page;
    use artbox\core\models\PageCategory;
    use artbox\core\models\User;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use artbox\core\components\imagemanager\models\ImageManager;
    use yii\bootstrap\ActiveForm;
    use yii\bootstrap\Nav;
    use yii\bootstrap\Html;
    use yii\db\ActiveQuery;
    use yii\helpers\Json;
    use yii\helpers\Url;
    use yii\web\View;
    use yii\widgets\Breadcrumbs;
    
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new \common\models\Order();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    /**
     * @var PageCategory[] $pageCategories
     */
    $pageCategories = PageCategory::find()
                                  ->with(
                                      [
                                          'lang',
                                          'pages' => function (ActiveQuery $query) {
                                              $query->with('lang.alias')
                                                    ->where(['in_menu' => true])
                                                    ->orderBy([ 'sort' => SORT_ASC ]);
                                          },
                                      ]
                                  )
                                  ->where([ 'status' => true ])
                                  ->orderBy([ 'sort' => SORT_ASC ])
                                  ->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = ImageManager::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getImagePathPrivate() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    )
?>

<?php $this->beginPage() ?>
  
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
      <title><?= Html::encode($seo->title) ?></title>
        <?php $this->head() ?>
    </head>
    <body>
        <?php $this->beginBody() ?>
      <!-- Google Analytics -->
      <script>
          (function(i, s, o, g, r, a, m) {
              i[ 'GoogleAnalyticsObject' ] = r;
              i[ r ] = i[ r ] || function() {
                      (i[ r ].q = i[ r ].q || []).push(arguments)
                  }, i[ r ].l = 1 * new Date();
              a = s.createElement(o), m = s.getElementsByTagName(o)[ 0 ];
              a.async = 1;
              a.src = g;
              m.parentNode.insertBefore(a, m)
          })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

          ga('create', <?=$settings->ga_code?>, 'auto');
          ga('send', 'pageview');
  
      </script>
      <div id="all">
        <header>
          <!-- *** TOP ***
_________________________________________________________ -->
          <div id="top">
            <div class="container">
              <div class="row">
                <div class="col-xs-5 contact">
                  <p class="hidden-sm hidden-xs">
                      <?php
                          if (!empty($settings->phone)) {
                              echo \Yii::t('app', 'Свяжитесь с нами ');
                              echo Html::a($settings->phone, "tel: {$settings->phone}");
                              if (!empty($settings->email)) {
                                  echo \Yii::t('app', ' или ');
                                  echo Html::a($settings->email, "mailto:$settings->email");
                              }
                          }
                      ?>
                  </p>
                  <p class="hidden-md hidden-lg">
                    <a href="#" data-animate-hover="pulse"><i class="fa fa-phone"></i></a>
                    <a href="#" data-animate-hover="pulse"><i class="fa fa-envelope"></i></a>
                  </p>
                </div>
                <div class="col-xs-7">
                  <div class="social">
                      <?php
                          if (!empty($settings->facebook)) {
                              echo Html::a(
                                  Html::icon(
                                      'facebook',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->facebook,
                                  [
                                      'class' => 'external facebook',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->vk)) {
                              echo Html::a(
                                  Html::icon(
                                      'vk',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->vk,
                                  [
                                      'class' => 'external vk',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->google)) {
                              echo Html::a(
                                  Html::icon(
                                      'google-plus',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->google,
                                  [
                                      'class' => 'external gplus',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->twitter)) {
                              echo Html::a(
                                  Html::icon(
                                      'twitter',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->twitter,
                                  [
                                      'class' => 'external twitter',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->ok)) {
                              echo Html::a(
                                  Html::icon(
                                      'odnoklassniki',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->ok,
                                  [
                                      'class' => 'external odnoklassniki',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->email)) {
                              echo Html::a(
                                  Html::icon(
                                      'envelope',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  "mailto:$settings->email",
                                  [
                                      'class' => 'email',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <!-- *** TOP END *** -->
          
          <!-- *** NAVBAR ***
  _________________________________________________________ -->
          <div class="navbar-affixed-top" data-spy="affix" data-offset-top="200">
            
            <div class="navbar navbar-default yamm" role="navigation" id="navbar">
              
              <div class="container">
                <div class="navbar-header">
                  
                  <a class="navbar-brand home" href="<?php echo Url::home(); ?>">
                      <?php
                          echo ImageHelper::set($logo)
                                          ->setHeight(42)
                                          ->renderImage(
                                              [
                                                  'alt' => $settings->name,
                                              ]
                                          )
                      ?>
                  </a>
                  <div class="navbar-buttons">
                    <button type="button" class="navbar-toggle btn-template-main" data-toggle="collapse" data-target="#navigation">
                      <span class="sr-only">Toggle navigation</span>
                      <i class="fa fa-align-justify"></i>
                    </button>
                  </div>
                </div>
                
                <div class="navbar-collapse collapse" id="navigation">
<!--                    --><?php
//                        $items = [];
//                        $items[] =  [
//                            'label' => 'ArtBox Core',
//                            'url'   => [ '/#ab-core' ],
//                            'options' => [
//                                'class' =>  'scroll-to',
//                            ],
//                        ];
//                        $items[] =  [
//                            'label' => 'ArtBox Каталог',
//                            'url'   => [ '/#ab-cat' ],
//                            'options' => [
//                                'class' =>  'scroll-to',
//                            ],
//                        ];
//                        $items[] =  [
//                            'label' => 'ArtBox Shop',
//                            'url'   => [ '/#ab-shop' ],
//                            'options' => [
//                                'class' =>  'scroll-to',
//                            ],
//                        ];
//                        $items[] =  [
//                            'label' => 'Контакты',
//                            'url'   => [ '/#ab-tar' ],
//                            'options' => [
//                                'class' =>  'scroll-to',
//                            ],
//                        ];
//                        echo Nav::widget(
//                            [
//                                'items'   => $items,
//                                'options' => [
//                                    'class' => 'nav navbar-nav navbar-right',
//                                ],
//                            ]
//                        );
//                    ?>
                    <ul id="w0" class="nav navbar-nav navbar-right">
                        <li><a href="#ab-core" class="scroll-to">ArtBox Core</a></li>
                        <li><a href="#ab-cat" class="scroll-to">ArtBox Каталог</a></li>
                        <li><a href="#ab-shop" class="scroll-to">ArtBox Shop</a></li>
                        <li><a href="#packages" class="scroll-to">Тарифы</a></li>
                    </ul>
                </div>
                
                
                <div class="collapse clearfix" id="search">
                  
                  <form class="navbar-form" role="search">
                    <div class="input-group">
                      <input type="text" class="form-control" placeholder="Поиск">
                      <span class="input-group-btn">

                    <button type="submit" class="btn btn-template-main"><i class="fa fa-search"></i></button>

                </span>
                    </div>
                  </form>
                
                </div>
                <!--/.nav-collapse -->
              
              </div>
            
            
            </div>
            <!-- /#navbar -->
          
          </div>
          
          <!-- *** NAVBAR END *** -->
        
        </header>
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        
        <div class="modal fade" id="feedback-modal" tabindex="-1" role="dialog" aria-labelledby="Login" aria-hidden="true">
              <div class="modal-dialog">

                  <div class="modal-content">
                      <div class="modal-header">
                          <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times</button>
                          <h3 class="modal-title" id="Login">Обратная связь</h3>
                      </div>
                      <div class="modal-body">

                          <?php $form = ActiveForm::begin(
                              [
                                  'id'     => 'feedback-form',
                                  'method' => 'POST',
                                  'action' => '/site/feedback',
                              ]
                          ); ?>

                          <?= $form->field($feedback, 'name')
                              ->textInput(); ?>

                          <?= $form->field($feedback, 'email')
                              ->textInput(); ?>

                          <?= $form->field($feedback, 'phone')
                              ->textInput(); ?>

                          <?= $form->field($feedback, 'message')
                              ->textarea(
                                  [
                                      'rows' => 4,
                                  ]
                              ); ?>

                          <p class="text-center">
                              <?= Html::submitButton(
                                  'Отправить',
                                  [
                                      'class' => 'send-form btn btn-lg btn-template-primary',
                                  ]
                              ) ?>
                          </p>

                          <?php ActiveForm::end(); ?>

                      </div>
                  </div>
              </div>
          </div>

        <!-- *** FeedBack MODAL END *** -->

        <!-- *** *** -->

          <div class="modal fade" id="order-modal" tabindex="-1" role="dialog" aria-labelledby="Login" aria-hidden="true">
              <div class="modal-dialog">

                  <div class="modal-content">
                      <div class="modal-header">
                          <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times</button>
                          <h3 class="modal-title" id="Login">Обратная связь</h3>
                      </div>
                      <div class="modal-body">

                          <?php $form = ActiveForm::begin(
                              [
                                  'id'     => 'order-form',
                                  'method' => 'POST',
                                  'action' => '/site/order',
                              ]
                          ); ?>

                          <?= $form->field($feedback, 'subject')
                              ->hiddenInput(); ?>

                          <?= $form->field($feedback, 'name')
                              ->textInput(); ?>

                          <?= $form->field($feedback, 'email')
                              ->textInput(); ?>

                          <?= $form->field($feedback, 'phone')
                              ->textInput(); ?>

                          <?= $form->field($feedback, 'message')
                              ->textarea(
                                  [
                                      'rows' => 4,
                                  ]
                              ); ?>

                          <p class="text-center">
                              <?= Html::submitButton(
                                  'Отправить',
                                  [
                                      'class' => 'send-form btn btn-lg btn-template-primary',
                                  ]
                              ) ?>
                          </p>

                          <?php ActiveForm::end(); ?>

                      </div>
                  </div>
              </div>
          </div>
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        
        <div class="modal fade" id="success-modal" tabindex="-1" role="dialog" aria-labelledby="Success" aria-hidden="true">
          <div class="modal-dialog">
            
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times</button>
                <h3 class="modal-title" id="Success">Success</h3>
              </div>
              <div class="modal-body">
                
                <p>Thank for your reply, we will call you, maybe.</p>
                <p class="text-center">
                  <button type="button" class="btn btn-template-primary" data-dismiss="modal">Закрыть</button>
                </p>
              </div>
            </div>
          </div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** Breadcrumbs *** -->
          <?php
              if (!$isHome) {
                  ?>
                <div id="heading-breadcrumbs">
                  <div class="container">
                    <div class="row">
                      <div class="col-md-7">
                        <h1><?= $seo->h1 ?></h1>
                      </div>
                      <div class="col-md-5">
                          <?= Breadcrumbs::widget(
                              [
                                  'links' => isset($this->params[ 'breadcrumbs' ]) ? $this->params[ 'breadcrumbs' ] : [],
                              ]
                          ) ?>
                      
                      </div>
                    </div>
                  </div>
                </div>
                  <?php
              }
          ?>
        <!-- *** Breadcrumbs END *** -->
          
          <?= $content ?>
        
        <!-- *** FOOTER ***
_________________________________________________________ -->
        
        <footer id="footer">
          <div class="container">
            <div class="col-md-6 col-sm-12">
                <?php
                    if (!empty($settings->about)) {
                        ?>
                      <h4><?php echo \Yii::t('app', 'О нас'); ?></h4>
                      <p><?php echo $settings->about; ?></p>
                        <?php
                    }
                ?>
              <a href="#" class="btn btn-template-transparent-primary" data-toggle="modal" data-target="#feedback-modal" data-title="Обратная связь">Свяжитесь с нами!</a>
            </div>
            
            <div class="col-md-4 col-sm-12 col-md-offset-2">
              
              <h4><?php echo \Yii::t('app', 'Контакты'); ?></h4>
              
              <p>
                  <?php
                      if (!empty($settings->office)) {
                          echo \Yii::t(
                                  'app',
                                  'Офис {office}',
                                  [
                                      'office' => $settings->office,
                                  ]
                              ) . Html::tag('br');
                      }
                      if (!empty($settings->street)) {
                          echo $settings->street;
                          if (!empty($settings->house)) {
                              echo " " . $settings->house;
                          }
                          echo Html::tag('br');
                      }
                      if (!empty($settings->city)) {
                          echo $settings->city;
                          echo Html::tag('br');
                      }
                      if (!empty($settings->country)) {
                          echo Html::tag('strong', $settings->country);
                      }
                  ?>
              </p>
              
              <hr class="hidden-md hidden-lg hidden-sm">
            
            </div>
            
            <div class="col-md-12">
              <p class="pull-left">&copy; <?= date('Y') ?>. <?= $settings->name; ?></p>
            </div>
          </div>
          <!-- /.container -->
        </footer>
        <!-- /#footer -->
        
        <!-- *** FOOTER END *** -->
        
        <span id="back-to-top" title="Back to top"><i class="fa fa-arrow-up"></i></span>
      
      </div>
      <!-- /#all -->
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>